Skip to contents

Returns FALSE if presolve, chordal decomposition or input_sparse_dropzeros has actually restructured this problem, which prevents data updates. Enabling one of those settings is not by itself enough to prevent updates; the transformation has to have taken place.

Usage

solver_is_update_allowed(solver)

Arguments

solver

a ClarabelSolver object created by clarabel_solver()

Value

logical scalar

Examples

if (FALSE) { # \dontrun{
solver_is_update_allowed(s)  # FALSE if the problem was restructured
} # }