Check if data updates are allowed on a persistent solver
Source:R/clarabel.R
solver_is_update_allowed.RdReturns FALSE if presolve, chordal decomposition or
input_sparse_dropzeros has actually restructured this problem, which
prevents data updates. Enabling one of those settings is not by itself
enough to prevent updates; the transformation has to have taken place.
Arguments
- solver
a
ClarabelSolverobject created byclarabel_solver()